==> kxmleditor_1.0.0.orig.tar.gz: kxmleditor-1.0.0/kxmleditor/dcopiface_shell_skel.cpp <==
/****************************************************************************
**
** DCOP Skeleton created by dcopidl2cpp from dcopiface_shell.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "./dcopiface_shell.h"

#include <kdatastream.h>


static const char* const KXMLEditorShellIface_ftable[3][3] = {
    { "QString", "Quit()", "Quit()" },
    { "ASYNC", "FileOpen()", "FileOpen()" },
    { 0, 0, 0 }
};

bool KXMLEditorShellIface::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorShellIface_ftable[0][1] ) { // QString Quit()
	replyType = KXMLEditorShellIface_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << Quit( );
    } else if ( fun == KXMLEditorShellIface_ftable[1][1] ) { // void FileOpen()
	replyType = KXMLEditorShellIface_ftable[1][0]; 
	FileOpen( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return TRUE;
}

QCStringList KXMLEditorShellIface::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KXMLEditorShellIface";
    return ifaces;
}

QCStringList KXMLEditorShellIface::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KXMLEditorShellIface_ftable[i][2]; i++ ) {
	QCString func = KXMLEditorShellIface_ftable[i][0];
	func += ' ';
	func += KXMLEditorShellIface_ftable[i][2];
	funcs << func;
    }
    return funcs;
}

==> kxmleditor_1.1.4.orig.tar.gz: kxmleditor-1.1.4/kxmleditor/dcopiface_shell_skel.cpp <==
/****************************************************************************
**
** DCOP Skeleton created by dcopidl2cpp from dcopiface_shell.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#include "dcopiface_shell.h"

#include <kdatastream.h>


static const char* const KXMLEditorShellIface_ftable[3][3] = {
    { "QString", "Quit()", "Quit()" },
    { "ASYNC", "FileOpen()", "FileOpen()" },
    { 0, 0, 0 }
};
static const int KXMLEditorShellIface_ftable_hiddens[2] = {
    0,
    0,
};

bool KXMLEditorShellIface::process(const QCString &fun, const QByteArray &data, QCString& replyType, QByteArray &replyData)
{
    if ( fun == KXMLEditorShellIface_ftable[0][1] ) { // QString Quit()
	replyType = KXMLEditorShellIface_ftable[0][0]; 
	QDataStream _replyStream( replyData, IO_WriteOnly );
	_replyStream << Quit( );
    } else if ( fun == KXMLEditorShellIface_ftable[1][1] ) { // void FileOpen()
	replyType = KXMLEditorShellIface_ftable[1][0]; 
	FileOpen( );
    } else {
	return DCOPObject::process( fun, data, replyType, replyData );
    }
    return true;
}

QCStringList KXMLEditorShellIface::interfaces()
{
    QCStringList ifaces = DCOPObject::interfaces();
    ifaces += "KXMLEditorShellIface";
    return ifaces;
}

QCStringList KXMLEditorShellIface::functions()
{
    QCStringList funcs = DCOPObject::functions();
    for ( int i = 0; KXMLEditorShellIface_ftable[i][2]; i++ ) {
	if (KXMLEditorShellIface_ftable_hiddens[i])
	    continue;
	QCString func = KXMLEditorShellIface_ftable[i][0];
	func += ' ';
	func += KXMLEditorShellIface_ftable[i][2];
	funcs << func;
    }
    return funcs;
}
